import asyncio
import aiohttp
import time
import random

async def get_user_input():
    qq = input("请输入QQ号: ").strip()
    prefix = input("请输入手机号的前三位: ").strip()
    suffix = input("请输入手机号的后两位: ").strip()
    city = input("请输入所在市区: ").strip()
    return qq, prefix, suffix, city

def generate_phone_numbers(prefix, suffix, count=1000):
    phone_numbers = set()  # 使用集合来自动去重
    while len(phone_numbers) < count:
        middle = str(random.randint(100000, 999999))  # 生成随机的6位中间数字
        phone_number = f"{prefix}{middle}{suffix}"
        phone_numbers.add(phone_number)
    return list(phone_numbers)

async def verify_binding(session, qq, phone_number):
    url = "https://zy.xywlapi.cc/qqcx2023"
    params = {
        "qq": qq,
        "phone": phone_number
    }
    try:
        async with session.get(url, params=params, timeout=5) as response:
            if response.status == 200:
                data = await response.json()
                return phone_number, data.get("status") == "success"
            else:
                print(f"请求失败,状态码: {response.status},手机号: {phone_number}")
                return phone_number, False
    except Exception as e:
        print(f"请求异常: {e},手机号: {phone_number}")
        return phone_number, False

async def main_async():
    # 添加您提供的信息
    print('满意')
    print('满意')
    print('二改倒卖死全家')
    
    qq, prefix, suffix, city = await get_user_input()
    print(f"您输入的QQ号是: {qq}")
    print(f"您输入的手机号前缀是: {prefix}")
    print(f"您输入的手机号后缀是: {suffix}")
    print(f"您输入的所在市区是: {city}")

    phone_numbers = generate_phone_numbers(prefix, suffix, 1000)
    print(f"生成了 {len(phone_numbers)} 个手机号。")

    async with aiohttp.ClientSession() as session:
        tasks = [verify_binding(session, qq, phone) for phone in phone_numbers]
        start_time = time.time()
        binding_results = []
        for task in asyncio.as_completed(tasks):
            phone, is_bound = await task
            if is_bound:
                binding_results.append(phone)
                print(f"手机号 {phone} 与QQ号 {qq} 绑定。✅")
            else:
                print(f"手机号 {phone} 未与QQ号 {qq} 绑定。❌")
            # 添加延迟,控制核验速度
            await asyncio.sleep(random.uniform(0.1, 0.5))  # 延迟0.1到0.5秒
        end_time = time.time()
        print(f"总共 {len(binding_results)} 个手机号与QQ号 {qq} 绑定。")
        print(f"验证耗时: {end_time - start_time:.2f} 秒")

if __name__ == "__main__":
    asyncio.run(main_async())
